fnss.topologies.topology.DirectedTopology.edges_iter — FNSS 0.5.0 documentation

### Navigation

- index
- modules |
- modules |
- FNSS 0.5.0 documentation »

# fnss.topologies.topology.DirectedTopology.edges_iter

`DirectedTopology.` `edges_iter`(nbunch=None, data=False)

  Return an iterator over the edges.

  Edges are returned as tuples with optional data in the order (node, neighbor, data).

  Parameters : | nbunch : iterable container, optional (default= all nodes) A container of nodes. The container will be iterated through once. data : bool, optional (default=False) If True, return edge attribute dict in 3-tuple (u,v,data).
  Returns : | edge_iter : iterator An iterator of (u,v) or (u,v,d) tuples of edges.

  See also

  `edges`
    return a list of edges

  Notes

  Nodes in nbunch that are not in the graph will be (quietly) ignored. For directed graphs this returns the out-edges.

  Examples

      >>> G = nx.DiGraph()   # or MultiDiGraph, etc
      >>> G.add_path([0,1,2,3])
      >>> [e for e in G.edges_iter()]
      [(0, 1), (1, 2), (2, 3)]
      >>> list(G.edges_iter(data=True)) # default data is {} (empty dict)
      [(0, 1, {}), (1, 2, {}), (2, 3, {})]
      >>> list(G.edges_iter([0,2]))
      [(0, 1), (2, 3)]
      >>> list(G.edges_iter(0))
      [(0, 1)]

### Navigation

- index
- modules |
- modules |
- FNSS 0.5.0 documentation »